( cd opt/kde/share/apps/amor ; rm -rf tips )
( cd opt/kde/share/apps/amor ; ln -sf /opt/kde/share/apps/amor/tips-en tips )
( cd opt/kde/share/doc/HTML/en/amor ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/amor ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kodo ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kodo ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kmoon ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmoon ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kteatime ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kteatime ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kweather ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kweather ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kworldclock ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kworldclock ; ln -sf /opt/kde/share/doc/HTML/en/common common )
